@@ -1,13 +1,13 @@
 package Perinci::Sub::Gen::AccessTable;
 
-our $DATE = '2015-07-15'; # DATE
-our $VERSION = '0.52'; # VERSION
+our $DATE = '2015-08-18'; # DATE
+our $VERSION = '0.53'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 use experimental 'smartmatch';
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Function::Fallback::CoreOrPP qw(clone);
 use List::Util qw(shuffle);
@@ -1484,7 +1484,7 @@ Perinci::Sub::Gen::AccessTable - Generate function (and its metadata) to read ta
 
 =head1 VERSION
 
-This document describes version 0.52 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2015-07-15.
+This document describes version 0.53 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
@@ -1593,8 +1593,9 @@ L<Perinci::Access::HTTP::Server>, or consumed normally by Perl programs.
 
 =head2 gen_read_table_func(%args) -> [status, msg, result, meta]
 
-Generate function (and its metadata) to read table data.
+{en_US Generate function (and its metadata) to read table data}.
 
+{en_US 
 The generated function acts like a simple single table SQL SELECT query,
 featuring filtering, ordering, and paging, but using arguments as the 'query
 language'. The generated function is suitable for exposing a table data from an
@@ -1681,6 +1682,7 @@ with field matching (or not matching) certain value (regex) (or will be
 included. Function will return 400 if regex is invalid. These arguments will
 not be generated if 'filterable_regex' clause in field specification is set
 to 0.
+}
 
 =back
 
@@ -1692,12 +1694,13 @@ Arguments ('*' denotes required arguments):
 
 =item * B<case_insensitive_search> => I<bool> (default: 1)
 
-Decide whether generated function will perform case-insensitive search.
+{en_US Decide whether generated function will perform case-insensitive search}.
 
 =item * B<custom_filters> => I<hash>
 
-Supply custom filters.
+{en_US Supply custom filters}.
 
+{en_US 
 A hash of filter name and definitions. Filter name will be used as generated
 function's argument and must not clash with other arguments. Filter definition
 is a hash containing these keys: I<meta> (hash, argument metadata), I<code>,
@@ -1707,92 +1710,103 @@ Code will be called for each record to be filtered and will be supplied ($r, $v,
 $opts) where $v is the filter value (from the function argument) and $r the
 hashref record value. $opts is currently empty. Code should return true if
 record satisfies the filter.
+}
 
 =item * B<custom_search> => I<code>
 
-Supply custom searching for generated function.
+{en_US Supply custom searching for generated function}.
 
+{en_US 
 Code will be supplied ($r, $q, $opts) where $r is the record (hashref), $q is
 the search term (from the function argument 'q'), and $opts is {ci=>0|1}. Code
 should return true if record matches search term.
+}
 
 =item * B<default_arg_values> => I<hash>
 
-Specify defaults for generated function's arguments.
+{en_US Specify defaults for generated function's arguments}.
 
+{en_US 
 Can be used to supply default filters, e.g.
 
  # limit years for credit card expiration date
  { "year.min" => $curyear, "year.max" => $curyear+10, }
 
+}
+
 =item * B<default_detail> => I<bool>
 
-Supply default 'detail' value for function arg spec.
+{en_US Supply default 'detail' value for function arg spec}.
 
 =item * B<default_fields> => I<str>
 
-Supply default 'fields' value for function arg spec.
+{en_US Supply default 'fields' value for function arg spec}.
 
 =item * B<default_random> => I<bool>
 
-Supply default 'random' value in generated function's metadata.
+{en_US Supply default 'random' value in generated function's metadata}.
 
 =item * B<default_result_limit> => I<int>
 
-Supply default 'result_limit' value in generated function's metadata.
+{en_US Supply default 'result_limit' value in generated function's metadata}.
 
 =item * B<default_sort> => I<str>
 
-Supply default 'sort' value in generated function's metadata.
+{en_US Supply default 'sort' value in generated function's metadata}.
 
 =item * B<default_with_field_names> => I<bool>
 
-Supply default 'with_field_names' value in generated function's metadata.
+{en_US Supply default 'with_field_names' value in generated function's metadata}.
 
 =item * B<description> => I<str>
 
-Generated function's description.
+{en_US Generated function's description}.
 
 =item * B<detail_aliases> => I<hash>
 
 =item * B<enable_field_selection> => I<bool> (default: 1)
 
-Decide whether generated function will support field selection (the `fields` argument).
+{en_US Decide whether generated function will support field selection (the `fields` argument)}.
 
 =item * B<enable_filtering> => I<bool> (default: 1)
 
-Decide whether generated function will support filtering (the FIELD, FIELD.is, FIELD.min, etc arguments).
+{en_US Decide whether generated function will support filtering (the FIELD, FIELD.is, FIELD.min, etc arguments)}.
 
 =item * B<enable_ordering> => I<bool> (default: 1)
 
-Decide whether generated function will support ordering (the `sort` & `random` arguments).
+{en_US Decide whether generated function will support ordering (the `sort` & `random` arguments)}.
 
 =item * B<enable_paging> => I<bool> (default: 1)
 
-Decide whether generated function will support paging (the `result_limit` & `result_start` arguments).
+{en_US Decide whether generated function will support paging (the `result_limit` & `result_start` arguments)}.
 
 =item * B<enable_random_ordering> => I<bool> (default: 1)
 
-Decide whether generated function will support random ordering (the `random` argument).
+{en_US Decide whether generated function will support random ordering (the `random` argument)}.
 
+{en_US 
 Ordering must also be enabled (C<enable_ordering>).
+}
 
 =item * B<enable_search> => I<bool> (default: 1)
 
-Decide whether generated function will support searching (argument q).
+{en_US Decide whether generated function will support searching (argument q)}.
 
+{en_US 
 Filtering must also be enabled (C<enable_filtering>).
+}
 
 =item * B<extra_args> => I<hash>
 
-Extra arguments for the generated function.
+{en_US Extra arguments for the generated function}.
 
 =item * B<fields_aliases> => I<hash>
 
 =item * B<hooks> => I<hash>
 
-Supply hooks.
+{en_US Supply hooks}.
 
+{en_US 
 You can instruct the generated function to execute codes in various stages by
 using hooks. Currently available hooks are: C<before_parse_query>,
 C<after_parse_query>, C<before_fetch_data>, C<after_fetch_data>, C<before_return>.
@@ -1807,19 +1821,23 @@ returned to user).
 Hook should return nothing or a false value on success. It can abort execution
 of the generated function if it returns an envelope response (an array). On that
 case, the function will return with this return value.
+}
 
 =item * B<install> => I<bool> (default: 1)
 
-Whether to install generated function (and metadata).
+{en_US Whether to install generated function (and metadata)}.
 
+{en_US 
 By default, generated function will be installed to the specified (or caller's)
 package, as well as its generated metadata into %SPEC. Set this argument to
 false to skip installing.
+}
 
 =item * B<langs> => I<array[str]> (default: ["en_US"])
 
-Choose language for function metadata.
+{en_US Choose language for function metadata}.
 
+{en_US 
 This function can generate metadata containing text from one or more languages.
 For example if you set 'langs' to ['en_US', 'id_ID'] then the generated function
 metadata might look something like this:
@@ -1837,18 +1855,22 @@ metadata might look something like this:
      ...
  }
 
+}
+
 =item * B<name> => I<str>
 
-Generated function's name, e.g. `myfunc`.
+{en_US Generated function's name, e.g. `myfunc`}.
 
 =item * B<package> => I<str>
 
-Generated function's package, e.g. `My::Package`.
+{en_US Generated function's package, e.g. `My::Package`}.
 
+{en_US 
 This is needed mostly for installing the function. You usually don't need to
 supply this if you set C<install> to false.
 
 If not specified, caller's package will be used by default.
+}
 
 =item * B<query_aliases> => I<hash>
 
@@ -1862,12 +1884,13 @@ If not specified, caller's package will be used by default.
 
 =item * B<summary> => I<str>
 
-Generated function's summary.
+{en_US Generated function's summary}.
 
 =item * B<table_data>* => I<array|code>
 
-Data.
+{en_US Data}.
 
+{en_US 
 Table data is either an AoH or AoA. Or you can also pass a Perl subroutine (see
 below).
 
@@ -1889,11 +1912,13 @@ that are mentioned in either filtering arguments or fields or ordering,
 'requested_fields' (fields mentioned in list of fields to be returned),
 'sort_fields' (fields mentioned in sort arguments), 'filter_fields' (fields
 mentioned in filter arguments).
+}
 
 =item * B<table_spec>* => I<hash>
 
-Table specification.
+{en_US Table specification}.
 
+{en_US 
 See C<TableDef> for more details.
 
 A hashref with these required keys: 'fields', 'pk'. 'fields' is a hashref of
@@ -1906,17 +1931,20 @@ the record, required with AoA data) and these optional clauses: 'sortable' (a
 boolean stating whether field can be sorted, default is true), 'filterable' (a
 boolean stating whether field can be mentioned in filter options, default is
 true).
+}
 
 =item * B<with_field_names_aliases> => I<hash>
 
 =item * B<word_search> => I<bool> (default: 0)
 
-Decide whether generated function will perform word searching instead of string searching.
+{en_US Decide whether generated function will perform word searching instead of string searching}.
 
+{en_US 
 For example, if search term is 'pine' and field value is 'green pineapple',
 search will match if word_search=false, but won't match under word_search.
 
 This will not have effect under 'custom_search'.
+}
 
 =back
 
@@ -1929,7 +1957,10 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-Return value: A hash containing generated function, metadata (hash)
+Return value: {en_US A hash containing generated function, metadata} (hash)
+
+
+{en_US }
 
 =head1 CAVEATS
 
