@@ -2,7 +2,7 @@ use 5.010;
 use strict;
 use warnings;
 use experimental 'smartmatch';
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Perinci::Sub::Gen::AccessTable qw(gen_read_table_func);
 use Test::More 0.96;
